==> jc-1.4.0.tar.gz: javax/xml/validation/Schema.c <==
// public abstract class javax.xml.validation.Schema

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 1ae5342d33750dd0 javax_xml_validation_Schema
// @dep_class ab0db23113c8d5db javax_xml_validation_Validator
// @dep_class afedc730322b7df javax_xml_validation_ValidatorHandler

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_xml_validation_Schema
// @dep_header javax_xml_validation_Validator
// @dep_header javax_xml_validation_ValidatorHandler

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/xml/validation/Schema.h"
#include "javax/xml/validation/Validator.h"
#include "javax/xml/validation/ValidatorHandler.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_javax_xml_validation_Schema$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_xml_validation_Schema$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_xml_validation_Schema$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_xml_validation_Schema$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_xml_validation_Schema$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_javax_xml_validation_Schema$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_xml_validation_Schema$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_validation_Schema, _init$52f4ad9f2989aeee);

void
_jc_javax_xml_validation_Schema$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_xml_validation_Schema$object *this)
{
	struct _jc_javax_xml_validation_Schema$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(51);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract javax.xml.validation.Validator newValidator()
//

static const unsigned char _jc_javax_xml_validation_Schema$param_ptypes$newValidator$f9d6848d47f5f710[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710 = {
	.name=			"newValidator",
	.signature=		"()Ljavax/xml/validation/Validator;",
	.class=			&_jc_javax_xml_validation_Schema$type,
	.return_type=		&_jc_javax_xml_validation_Validator$type,
	.param_ptypes=		&_jc_javax_xml_validation_Schema$param_ptypes$newValidator$f9d6848d47f5f710,
	.signature_hash=	_JC_JLONG(0xf9d6848d47f5f710),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_validation_Schema$vtable, javax_xml_validation_Schema.newValidator$f9d6848d47f5f710) / sizeof(void *),
	.num_parameters=	0,
};

_jc_javax_xml_validation_Validator$object *
_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710(_jc_env *const env, _jc_javax_xml_validation_Schema$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710);
}

//
// public abstract javax.xml.validation.ValidatorHandler newValidatorHandler()
//

static const unsigned char _jc_javax_xml_validation_Schema$param_ptypes$newValidatorHandler$0e0d41db26c98bf5[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5 = {
	.name=			"newValidatorHandler",
	.signature=		"()Ljavax/xml/validation/ValidatorHandler;",
	.class=			&_jc_javax_xml_validation_Schema$type,
	.return_type=		&_jc_javax_xml_validation_ValidatorHandler$type,
	.param_ptypes=		&_jc_javax_xml_validation_Schema$param_ptypes$newValidatorHandler$0e0d41db26c98bf5,
	.signature_hash=	_JC_JLONG(0xe0d41db26c98bf5),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_validation_Schema$vtable, javax_xml_validation_Schema.newValidatorHandler$0e0d41db26c98bf5) / sizeof(void *),
	.num_parameters=	0,
};

_jc_javax_xml_validation_ValidatorHandler$object *
_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5(_jc_env *const env, _jc_javax_xml_validation_Schema$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_xml_validation_Schema$methods[] = {
	&_jc_javax_xml_validation_Schema$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710,
	&_jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_xml_validation_Schema$instanceof_hash_bucket_80[] = {
	&_jc_javax_xml_validation_Schema$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_xml_validation_Schema$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_xml_validation_Schema$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[80]=	_jc_javax_xml_validation_Schema$instanceof_hash_bucket_80,
	[113]=	_jc_javax_xml_validation_Schema$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_xml_validation_Schema$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/xml/validation/Validator",	_JC_JLONG(0xab0db23113c8d5db) },
	{ "javax/xml/validation/ValidatorHandler",	_JC_JLONG(0xafedc730322b7df) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_xml_validation_Schema$vtype _jc_javax_xml_validation_Schema$type = {
    .type= {
	.name=			"javax/xml/validation/Schema",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x1ae5342d33750dd0),
		.source_file=		"Schema.java",
		.instance_size=		sizeof(_jc_javax_xml_validation_Schema$refs) + sizeof(_jc_javax_xml_validation_Schema$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_xml_validation_Schema$methods) / sizeof(*_jc_javax_xml_validation_Schema$methods),
		.methods=		_jc_javax_xml_validation_Schema$methods,
		.instanceof_hash_table=	_jc_javax_xml_validation_Schema$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_xml_validation_Schema$class_depends) / sizeof(*_jc_javax_xml_validation_Schema$class_depends),
		.class_depends=		_jc_javax_xml_validation_Schema$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_xml_validation_Schema= {
	    .newValidator$f9d6848d47f5f710=
		&_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710,
	    .newValidatorHandler$0e0d41db26c98bf5=
		&_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/xml/validation/Schema.c <==
// public abstract class javax.xml.validation.Schema

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 1ae5342d33750dd0 javax_xml_validation_Schema
// @dep_class ab0db23113c8d5db javax_xml_validation_Validator
// @dep_class afedc730322b7df javax_xml_validation_ValidatorHandler

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_xml_validation_Schema
// @dep_header javax_xml_validation_Validator
// @dep_header javax_xml_validation_ValidatorHandler

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/xml/validation/Schema.h"
#include "javax/xml/validation/Validator.h"
#include "javax/xml/validation/ValidatorHandler.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_javax_xml_validation_Schema$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_xml_validation_Schema$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_xml_validation_Schema$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_xml_validation_Schema$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_xml_validation_Schema$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_javax_xml_validation_Schema$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_xml_validation_Schema$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_validation_Schema, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_xml_validation_Schema$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_xml_validation_Schema$object *this)
{
	struct _jc_javax_xml_validation_Schema$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(51);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract javax.xml.validation.Validator newValidator()
//

static const unsigned char _jc_javax_xml_validation_Schema$param_ptypes$newValidator$f9d6848d47f5f710[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710 = {
	.name=			"newValidator",
	.signature=		"()Ljavax/xml/validation/Validator;",
	.class=			&_jc_javax_xml_validation_Schema$type,
	.return_type=		&_jc_javax_xml_validation_Validator$type,
	.param_ptypes=		&_jc_javax_xml_validation_Schema$param_ptypes$newValidator$f9d6848d47f5f710,
	.signature_hash=	_JC_JLONG(0xf9d6848d47f5f710),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_validation_Schema$vtable, javax_xml_validation_Schema.newValidator$f9d6848d47f5f710) / sizeof(void *),
	.num_parameters=	0,
};

_jc_javax_xml_validation_Validator$object * _JC_JCNI_ATTR
_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710(_jc_env *const env, _jc_javax_xml_validation_Schema$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710);
}

//
// public abstract javax.xml.validation.ValidatorHandler newValidatorHandler()
//

static const unsigned char _jc_javax_xml_validation_Schema$param_ptypes$newValidatorHandler$0e0d41db26c98bf5[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5 = {
	.name=			"newValidatorHandler",
	.signature=		"()Ljavax/xml/validation/ValidatorHandler;",
	.class=			&_jc_javax_xml_validation_Schema$type,
	.return_type=		&_jc_javax_xml_validation_ValidatorHandler$type,
	.param_ptypes=		&_jc_javax_xml_validation_Schema$param_ptypes$newValidatorHandler$0e0d41db26c98bf5,
	.signature_hash=	_JC_JLONG(0xe0d41db26c98bf5),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_validation_Schema$vtable, javax_xml_validation_Schema.newValidatorHandler$0e0d41db26c98bf5) / sizeof(void *),
	.num_parameters=	0,
};

_jc_javax_xml_validation_ValidatorHandler$object * _JC_JCNI_ATTR
_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5(_jc_env *const env, _jc_javax_xml_validation_Schema$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_xml_validation_Schema$methods[] = {
	&_jc_javax_xml_validation_Schema$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710,
	&_jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_xml_validation_Schema$instanceof_hash_bucket_80[] = {
	&_jc_javax_xml_validation_Schema$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_xml_validation_Schema$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_xml_validation_Schema$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[80]=	_jc_javax_xml_validation_Schema$instanceof_hash_bucket_80,
	[101]=	_jc_javax_xml_validation_Schema$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_xml_validation_Schema$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/xml/validation/Validator",	_JC_JLONG(0xab0db23113c8d5db) },
	{ "javax/xml/validation/ValidatorHandler",	_JC_JLONG(0xafedc730322b7df) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_xml_validation_Schema$vtype _jc_javax_xml_validation_Schema$type = {
    .type= {
	.name=			"javax/xml/validation/Schema",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x1ae5342d33750dd0),
		.source_file=		"Schema.java",
		.instance_size=		sizeof(_jc_javax_xml_validation_Schema$refs) + sizeof(_jc_javax_xml_validation_Schema$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_xml_validation_Schema$methods) / sizeof(*_jc_javax_xml_validation_Schema$methods),
		.methods=		_jc_javax_xml_validation_Schema$methods,
		.instanceof_hash_table=	_jc_javax_xml_validation_Schema$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_xml_validation_Schema$class_depends) / sizeof(*_jc_javax_xml_validation_Schema$class_depends),
		.class_depends=		_jc_javax_xml_validation_Schema$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_xml_validation_Schema= {
	    .newValidator$f9d6848d47f5f710=
		&_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710,
	    .newValidatorHandler$0e0d41db26c98bf5=
		&_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5,
	},
    }
};
